@@ -99,6 +99,7 @@ typedef struct {
   guint              idle_timer;
   gint64             last_input;
   PhoshAuth         *auth;
+  GSettings         *keypad_settings;
 
   /* Call page */
   HdyDeck           *deck;
@@ -282,8 +283,7 @@ auth_async_cb (PhoshAuth *auth, GAsyncResult *result, PhoshLockscreen *self)
                                   shake_label,
                                   g_variant_ref_sink (g_variant_new_int64 (now)),
                                   (GDestroyNotify) g_variant_unref);
-
-
+    phosh_keypad_distribute (PHOSH_KEYPAD (priv->keypad));
   }
   priv->last_input = g_get_monotonic_time ();
   g_object_unref (self);
@@ -688,6 +688,10 @@ phosh_lockscreen_constructed (GObject *object)
                           priv->keypad_revealer, "reveal-child",
                           G_BINDING_SYNC_CREATE | G_BINDING_INVERT_BOOLEAN);
 
+  priv->keypad_settings = g_settings_new("sm.puri.phosh.lockscreen");
+  g_settings_bind (priv->keypad_settings, "shuffle-keypad",
+                   priv->keypad, "shuffle",
+                   G_SETTINGS_BIND_GET);
 }
 
 static void
@@ -711,6 +715,7 @@ phosh_lockscreen_dispose (GObject *object)
   g_clear_handle_id (&priv->idle_timer, g_source_remove);
   g_clear_object (&priv->calls_manager);
   g_clear_pointer (&priv->active, g_free);
+  g_clear_object (&priv->keypad_settings);
 
   G_OBJECT_CLASS (phosh_lockscreen_parent_class)->dispose (object);
 }
