@@ -139,6 +139,9 @@ struct _PhoshMonitor {
 
   gboolean wl_output_done;
   gboolean xdg_output_done;
+
+  struct zwlr_gamma_control_v1 *gamma_control;
+  guint32 n_gamma_entries;
 };
 
 G_DECLARE_FINAL_TYPE (PhoshMonitor, phosh_monitor, PHOSH, MONITOR, GObject)
